@@ -16,6 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import importlib
+import pprint
 import textwrap
 from types import ModuleType
 from typing import Any, Dict, Iterable, NamedTuple, Optional, Tuple, Type
@@ -35,7 +36,7 @@ __all__ = [
 
 
 _URL_ATTRIBUTE_ERROR = (
-    f"https://python-gitlab.readthedocs.io/en/{gitlab.__version__}/"
+    f"https://python-gitlab.readthedocs.io/en/v{gitlab.__version__}/"
     f"faq.html#attribute-error-list"
 )
 
@@ -147,6 +148,14 @@ class RESTObject(object):
         data.update(self._updated_attrs)
         return f"{type(self)} => {data}"
 
+    def pformat(self) -> str:
+        data = self._attrs.copy()
+        data.update(self._updated_attrs)
+        return f"{type(self)} => \n{pprint.pformat(data)}"
+
+    def pprint(self) -> None:
+        print(self.pformat())
+
     def __repr__(self) -> str:
         if self._id_attr:
             return f"<{self.__class__.__name__} {self._id_attr}:{self.get_id()}>"
@@ -208,6 +217,15 @@ class RESTObject(object):
             return None
         return getattr(self, self._id_attr)
 
+    @property
+    def encoded_id(self) -> Any:
+        """Ensure that the ID is url-encoded so that it can be safely used in a URL
+        path"""
+        obj_id = self.get_id()
+        if isinstance(obj_id, str):
+            obj_id = gitlab.utils.EncodedId(obj_id)
+        return obj_id
+
     @property
     def attributes(self) -> Dict[str, Any]:
         d = self.__dict__["_updated_attrs"].copy()
