@@ -18,6 +18,7 @@ from .custom_attributes import GroupCustomAttributeManager  # noqa: F401
 from .deploy_tokens import GroupDeployTokenManager  # noqa: F401
 from .epics import GroupEpicManager  # noqa: F401
 from .export_import import GroupExportManager, GroupImportManager  # noqa: F401
+from .group_access_tokens import GroupAccessTokenManager  # noqa: F401
 from .hooks import GroupHookManager  # noqa: F401
 from .issues import GroupIssueManager  # noqa: F401
 from .labels import GroupLabelManager  # noqa: F401
@@ -49,6 +50,7 @@ __all__ = [
 class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
     _short_print_attr = "name"
 
+    access_tokens: GroupAccessTokenManager
     accessrequests: GroupAccessRequestManager
     audit_events: GroupAuditEventManager
     badges: GroupBadgeManager
@@ -90,15 +92,37 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabTransferProjectError: If the project could not be transferred
         """
-        path = f"/groups/{self.id}/projects/{project_id}"
+        path = f"/groups/{self.encoded_id}/projects/{project_id}"
         self.manager.gitlab.http_post(path, **kwargs)
 
+    @cli.register_custom_action("Group", tuple(), ("group_id",))
+    @exc.on_http_error(exc.GitlabGroupTransferError)
+    def transfer(self, group_id: Optional[int] = None, **kwargs: Any) -> None:
+        """Transfer the group to a new parent group or make it a top-level group.
+
+        Requires GitLab ≥14.6.
+
+        Args:
+            group_id: ID of the new parent group. When not specified,
+                the group to transfer is instead turned into a top-level group.
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabGroupTransferError: If the group could not be transferred
+        """
+        path = f"/groups/{self.encoded_id}/transfer"
+        post_data = {}
+        if group_id is not None:
+            post_data["group_id"] = group_id
+        self.manager.gitlab.http_post(path, post_data=post_data, **kwargs)
+
     @cli.register_custom_action("Group", ("scope", "search"))
     @exc.on_http_error(exc.GitlabSearchError)
     def search(
         self, scope: str, search: str, **kwargs: Any
     ) -> Union[gitlab.GitlabList, List[Dict[str, Any]]]:
-        """Search the group resources matching the provided string.'
+        """Search the group resources matching the provided string.
 
         Args:
             scope: Scope of the search
@@ -113,7 +137,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             A list of dicts describing the resources found.
         """
         data = {"scope": scope, "search": search}
-        path = f"/groups/{self.get_id()}/search"
+        path = f"/groups/{self.encoded_id}/search"
         return self.manager.gitlab.http_list(path, query_data=data, **kwargs)
 
     @cli.register_custom_action("Group", ("cn", "group_access", "provider"))
@@ -134,7 +158,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabCreateError: If the server cannot perform the request
         """
-        path = f"/groups/{self.get_id()}/ldap_group_links"
+        path = f"/groups/{self.encoded_id}/ldap_group_links"
         data = {"cn": cn, "group_access": group_access, "provider": provider}
         self.manager.gitlab.http_post(path, post_data=data, **kwargs)
 
@@ -154,7 +178,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabDeleteError: If the server cannot perform the request
         """
-        path = f"/groups/{self.get_id()}/ldap_group_links"
+        path = f"/groups/{self.encoded_id}/ldap_group_links"
         if provider is not None:
             path += f"/{provider}"
         path += f"/{cn}"
@@ -172,7 +196,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabCreateError: If the server cannot perform the request
         """
-        path = f"/groups/{self.get_id()}/ldap_sync"
+        path = f"/groups/{self.encoded_id}/ldap_sync"
         self.manager.gitlab.http_post(path, **kwargs)
 
     @cli.register_custom_action("Group", ("group_id", "group_access"), ("expires_at",))
@@ -198,7 +222,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
         Returns:
             Group
         """
-        path = f"/groups/{self.get_id()}/share"
+        path = f"/groups/{self.encoded_id}/share"
         data = {
             "group_id": group_id,
             "group_access": group_access,
@@ -222,7 +246,7 @@ class Group(SaveMixin, ObjectDeleteMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabDeleteError: If the server failed to perform the request
         """
-        path = f"/groups/{self.get_id()}/share/{group_id}"
+        path = f"/groups/{self.encoded_id}/share/{group_id}"
         self.manager.gitlab.http_delete(path, **kwargs)
 
 
