@@ -3,13 +3,29 @@ import pytest
 import gitlab
 
 
+@pytest.fixture(scope="session")
+def fixture_dir(test_dir):
+    return test_dir / "unit" / "fixtures"
+
+
 @pytest.fixture
 def gl():
     return gitlab.Gitlab(
         "http://localhost",
         private_token="private_token",
         ssl_verify=True,
-        api_version=4,
+        api_version="4",
+    )
+
+
+@pytest.fixture
+def gl_retry():
+    return gitlab.Gitlab(
+        "http://localhost",
+        private_token="private_token",
+        ssl_verify=True,
+        api_version="4",
+        retry_transient_errors=True,
     )
 
 
@@ -17,7 +33,7 @@ def gl():
 @pytest.fixture
 def gl_trailing():
     return gitlab.Gitlab(
-        "http://localhost/", private_token="private_token", api_version=4
+        "http://localhost/", private_token="private_token", api_version="4"
     )
 
 
