@@ -144,6 +144,24 @@ class TestRESTObject:
         obj.id = None
         assert obj.get_id() is None
 
+    def test_encoded_id(self, fake_manager):
+        obj = FakeObject(fake_manager, {"foo": "bar"})
+        obj.id = 42
+        assert 42 == obj.encoded_id
+
+        obj.id = None
+        assert obj.encoded_id is None
+
+        obj.id = "plain"
+        assert "plain" == obj.encoded_id
+
+        obj.id = "a/path"
+        assert "a%2Fpath" == obj.encoded_id
+
+        # If you assign it again it does not double URL-encode
+        obj.id = obj.encoded_id
+        assert "a%2Fpath" == obj.encoded_id
+
     def test_custom_id_attr(self, fake_manager):
         class OtherFakeObject(FakeObject):
             _id_attr = "foo"
@@ -201,3 +219,33 @@ class TestRESTObject:
         obj1 = FakeObject(fake_manager, {"attr1": "foo"})
         obj2 = FakeObject(fake_manager, {"attr1": "bar"})
         assert obj1 != obj2
+
+    def test_dunder_str(self, fake_manager):
+        fake_object = FakeObject(fake_manager, {"attr1": "foo"})
+        assert str(fake_object) == (
+            "<class 'tests.unit.test_base.FakeObject'> => {'attr1': 'foo'}"
+        )
+
+    def test_pformat(self, fake_manager):
+        fake_object = FakeObject(
+            fake_manager, {"attr1": "foo" * 10, "ham": "eggs" * 15}
+        )
+        assert fake_object.pformat() == (
+            "<class 'tests.unit.test_base.FakeObject'> => "
+            "\n{'attr1': 'foofoofoofoofoofoofoofoofoofoo',\n"
+            " 'ham': 'eggseggseggseggseggseggseggseggseggseggseggseggseggseggseggs'}"
+        )
+
+    def test_pprint(self, capfd, fake_manager):
+        fake_object = FakeObject(
+            fake_manager, {"attr1": "foo" * 10, "ham": "eggs" * 15}
+        )
+        result = fake_object.pprint()
+        assert result is None
+        stdout, stderr = capfd.readouterr()
+        assert stdout == (
+            "<class 'tests.unit.test_base.FakeObject'> => "
+            "\n{'attr1': 'foofoofoofoofoofoofoofoofoofoo',\n"
+            " 'ham': 'eggseggseggseggseggseggseggseggseggseggseggseggseggseggseggs'}\n"
+        )
+        assert stderr == ""
